pub enum JwksClientError {
OidcProviderMetadataRequestFailed(Error),
InvalidOidcProviderMetadataResponse(Error),
JwksRequestFailed(Error),
InvalidJwksResponse(Error),
}Expand description
Possible errors when fetching the JWKS.
Variants
OidcProviderMetadataRequestFailed(Error)
OIDC provider metadata request failed.
Possible reasons:
- Network error.
- Wrong OIDC provider metadata URL.
- OIDC provider metadata provider is not available.
InvalidOidcProviderMetadataResponse(Error)
OIDC provider metadata request succeeded, but it does not match the expected OIDC provider
metadata schema (response_body["jwks_uri"] is missing, or is not a valid URL).
JwksRequestFailed(Error)
JWKS request failed.
Possible reasons:
- Network error.
- Wrong JWKS URL.
- JWKS provider is not available.
InvalidJwksResponse(Error)
JWKS request succeeded, but it does not match the expected JWKS schema.